Index: src/serialize.cc |
diff --git a/src/serialize.cc b/src/serialize.cc |
index 86348aefee917c2c921fb806bf2d8df2f599e024..b69894b29556bc7de0df5be9ac58c5570f2df383 100644 |
--- a/src/serialize.cc |
+++ b/src/serialize.cc |
@@ -1163,16 +1163,16 @@ void Deserializer::ReadData(Object** current, Object** limit, int source_space, |
// allocation point and write a pointer to it to the current object. |
ALL_SPACES(kBackref, kPlain, kStartOfObject) |
ALL_SPACES(kBackrefWithSkip, kPlain, kStartOfObject) |
-#if defined(V8_TARGET_ARCH_MIPS) || V8_OOL_CONSTANT_POOL || \ |
- defined(V8_TARGET_ARCH_MIPS64) |
+#if defined(V8_TARGET_ARCH_MIPS) || defined(V8_TARGET_ARCH_MIPS64) || \ |
+ defined(V8_TARGET_ARCH_PPC) || V8_OOL_CONSTANT_POOL |
// Deserialize a new object from pointer found in code and write |
// a pointer to it to the current object. Required only for MIPS or ARM |
// with ool constant pool, and omitted on the other architectures because |
// it is fully unrolled and would cause bloat. |
ALL_SPACES(kNewObject, kFromCode, kStartOfObject) |
// Find a recently deserialized code object using its offset from the |
// current allocation point and write a pointer to it to the current |
// object. Required only for MIPS or ARM with ool constant pool. |
ALL_SPACES(kBackref, kFromCode, kStartOfObject) |
ALL_SPACES(kBackrefWithSkip, kFromCode, kStartOfObject) |
#endif |
@@ -1189,7 +1189,7 @@ void Deserializer::ReadData(Object** current, Object** limit, int source_space, |
CASE_STATEMENT(kRootArray, kPlain, kStartOfObject, 0) |
CASE_BODY(kRootArray, kPlain, kStartOfObject, 0) |
#if defined(V8_TARGET_ARCH_MIPS) || V8_OOL_CONSTANT_POOL || \ |
- defined(V8_TARGET_ARCH_MIPS64) |
+ defined(V8_TARGET_ARCH_MIPS64) || defined(V8_TARGET_ARCH_PPC) |
// Find an object in the roots array and write a pointer to it to in code. |
CASE_STATEMENT(kRootArray, kFromCode, kStartOfObject, 0) |
CASE_BODY(kRootArray, kFromCode, kStartOfObject, 0) |
@@ -1163,16 +1163,16 @@ void Deserializer::ReadData(Object** current, Object** limit, int source_space, |
// Deserialize a new object from pointer found in code and write |
- // a pointer to it to the current object. Required only for MIPS or ARM |
- // with ool constant pool, and omitted on the other architectures because |
- // it is fully unrolled and would cause bloat. |
+ // a pointer to it to the current object. Required only for MIPS, PPC or |
+ // ARM with ool constant pool, and omitted on the other architectures |
+ // because it is fully unrolled and would cause bloat. |
ALL_SPACES(kNewObject, kFromCode, kStartOfObject) |
// Find a recently deserialized code object using its offset from the |
@@ -1163,16 +1163,16 @@ void Deserializer::ReadData(Object** current, Object** limit, int source_space, |
// Find a recently deserialized code object using its offset from the |
// current allocation point and write a pointer to it to the current |
- // object. Required only for MIPS or ARM with ool constant pool. |
+ // object. Required only for MIPS, PPC or ARM with ool constant pool. |
ALL_SPACES(kBackref, kFromCode, kStartOfObject) |
ALL_SPACES(kBackrefWithSkip, kFromCode, kStartOfObject) |